db_xrefs

- NCBI
- Skip to main content
- Skip to navigation
- Resources
  - All Resources
  - Chemicals & Bioassays
    - BioSystems
    - PubChem BioAssay
    - PubChem Compound
    - PubChem Structure Search
    - PubChem Substance
    - All Chemicals & Bioassays Resources...
  - DNA & RNA
    - BLAST (Basic Local Alignment Search Tool)
    - BLAST (Stand-alone)
    - E-Utilities
    - GenBank
    - GenBank: BankIt
    - GenBank: Sequin
    - GenBank: tbl2asn
    - Genome Workbench
    - Influenza Virus
    - Nucleotide Database
    - PopSet
    - Primer-BLAST
    - ProSplign
    - Reference Sequence (RefSeq)
    - RefSeqGene
    - Sequence Read Archive (SRA)
    - Splign
    - Trace Archive
    - All DNA & RNA Resources...
  - Data & Software
    - BLAST (Basic Local Alignment Search Tool)
    - BLAST (Stand-alone)
    - Cn3D
    - Conserved Domain Search Service (CD Search)
    - E-Utilities
    - GenBank: BankIt
    - GenBank: Sequin
    - GenBank: tbl2asn
    - Genome ProtMap
    - Genome Workbench
    - Primer-BLAST
    - ProSplign
    - PubChem Structure Search
    - SNP Submission Tool
    - Splign
    - Vector Alignment Search Tool (VAST)
    - All Data & Software Resources...
  - Domains & Structures
    - BioSystems
    - Cn3D
    - Conserved Domain Database (CDD)
    - Conserved Domain Search Service (CD Search)
    - Structure (Molecular Modeling Database)
    - Vector Alignment Search Tool (VAST)
    - All Domains & Structures Resources...
  - Genes & Expression
    - BioSystems
    - Database of Genotypes and Phenotypes (dbGaP)
    - E-Utilities
    - Gene
    - Gene Expression Omnibus (GEO) Database
    - Gene Expression Omnibus (GEO) Datasets
    - Gene Expression Omnibus (GEO) Profiles
    - Genome Workbench
    - HomoloGene
    - Online Mendelian Inheritance in Man (OMIM)
    - RefSeqGene
    - All Genes & Expression Resources...
  - Genetics & Medicine
    - Bookshelf
    - Database of Genotypes and Phenotypes (dbGaP)
    - Genetic Testing Registry
    - Influenza Virus
    - Online Mendelian Inheritance in Man (OMIM)
    - PubMed
    - PubMed Central (PMC)
    - PubMed Clinical Queries
    - RefSeqGene
    - All Genetics & Medicine Resources...
  - Genomes & Maps
    - Database of Genomic Structural Variation (dbVar)
    - GenBank: tbl2asn
    - Genome
    - Genome Project
    - Genome Data Viewer (GDV)
    - Genome ProtMap
    - Genome Workbench
    - Influenza Virus
    - Nucleotide Database
    - PopSet
    - ProSplign
    - Sequence Read Archive (SRA)
    - Splign
    - Trace Archive
    - All Genomes & Maps Resources...
  - Homology
    - BLAST (Basic Local Alignment Search Tool)
    - BLAST (Stand-alone)
    - BLAST Link (BLink)
    - Conserved Domain Database (CDD)
    - Conserved Domain Search Service (CD Search)
    - Genome ProtMap
    - HomoloGene
    - Protein Clusters
    - All Homology Resources...
  - Literature
    - Bookshelf
    - E-Utilities
    - Journals in NCBI Databases
    - MeSH Database
    - NCBI Handbook
    - NCBI Help Manual
    - NCBI News & Blog
    - PubMed
    - PubMed Central (PMC)
    - PubMed Clinical Queries
    - All Literature Resources...
  - Proteins
    - BioSystems
    - BLAST (Basic Local Alignment Search Tool)
    - BLAST (Stand-alone)
    - BLAST Link (BLink)
    - Conserved Domain Database (CDD)
    - Conserved Domain Search Service (CD Search)
    - E-Utilities
    - ProSplign
    - Protein Clusters
    - Protein Database
    - Reference Sequence (RefSeq)
    - All Proteins Resources...
  - Sequence Analysis
    - BLAST (Basic Local Alignment Search Tool)
    - BLAST (Stand-alone)
    - BLAST Link (BLink)
    - Conserved Domain Search Service (CD Search)
    - Genome ProtMap
    - Genome Workbench
    - Influenza Virus
    - Primer-BLAST
    - ProSplign
    - Splign
    - All Sequence Analysis Resources...
  - Taxonomy
    - Taxonomy
    - Taxonomy Browser
    - Taxonomy Common Tree
    - All Taxonomy Resources...
  - Training & Tutorials
    - NCBI Education Page
    - NCBI Handbook
    - NCBI Help Manual
    - NCBI News & Blog
    - All Training & Tutorials Resources...
  - Variation
    - Database of Genomic Structural Variation (dbVar)
    - Database of Genotypes and Phenotypes (dbGaP)
    - Database of Single Nucleotide Polymorphisms (dbSNP)
    - SNP Submission Tool
    - All Variation Resources...
- How To
  - All How To
  - Chemicals & Bioassays
  - DNA & RNA
  - Data & Software
  - Domains & Structures
  - Genes & Expression
  - Genetics & Medicine
  - Genomes & Maps
  - Homology
  - Literature
  - Proteins
  - Sequence Analysis
  - Taxonomy
  - Training & Tutorials
  - Variation
- About NCBI Accesskeys

My NCBI Sign in to NCBI Sign Out

# GenBank

## Public nucleic acid sequence repository

Search database
Search term

# db_xrefs

The `/db_xref` qualifier serves as a vehicle for linking DNA sequence records to other external databases.

The text below outlines the format and the present list of allowed database cross references. Inquiries about the addition of other database types should be made to one of the collaborating databases.

    Qualifier:       /db_xref="database:identifier"
    Definition:      database cross-reference: pointer to related information
                     in another database
    Scope:           all feature keys
    Value format:    "database:identifier" where database is the name of the
                     database containing related information, and
                     identifier is the internal identifier of the related
                     information according to the naming conventions of the
                     cross-referenced database.

    Examples:

    cross reference to GDB identifier:            /db_xref="GDB:39999"
    cross reference to Swiss-Prot entry:          /db_xref="Swiss-Prot:P12345"

For all databases types 'Case' is important. All member databases of the International Collaboration (DDBJ, ENA/EBI and GenBank/NCBI) may make recommendations for additions or removal of databases to this list at their convenience, and need not rely on the release cycle of the Feature Table documentation.

Database: Description of database, and type with example(s).

Presently the list includes:

db_xref List
AceView/WormGenes |  | AceView Worm Genome |  | /db_xref="AceView/WormGenes:vha-6"
AFTOL |  | Assembling the Fungal Tree of Life |  | /db_xref="AFTOL:959"
AntWeb |  | Ant Database |  | /db_xref="AntWeb:CASENT0058943-D01"
APHIDBASE |  | Aphid Genome Database |  | /db_xref="APHIDBASE:ACYPI007424"
ApiDB |  | Apicomplexan Database Resources |  | /db_xref="ApiDB:cgd1_1090"
ApiDB_CryptoDB |  | Cryptosporidium Genome Resources |  | /db_xref="ApiDB_CryptoDB:cgd7_20"
ApiDB_PlasmoDB |  | Plasmodium Genome Resources |  | /db_xref="ApiDB_PlasmoDB:PF11_0344"
ApiDB_ToxoDB |  | Toxoplasma Genome Resources |  | /db_xref="ApiDB_ToxoDB:49.m00014"
Araport |  | Arabidopsis Information Portal |  | /db_xref="Araport:AT1G01010"
ASAP |  | A Systematic Annotation Package for Community Analysis of Genomes |  | /db_xref="ASAP:ABE-0000006"
ATCC |  | American Type Culture Collection database |  | /db_xref="ATCC:123456"
ATCC(in host) |  | American Type Culture Collection database |  | /db_xref="ATCC(in host):123456"
ATCC(dna) |  | American Type Culture Collection database |  | /db_xref="ATCC(dna):123456”
Axeldb |  | A Xenopus laevis database |  | /db_xref="Axeldb:32B3.1"
BDGP_EST |  | Berkeley Drosophila Genome Project EST database |  | /db_xref="BDGP_EST:123456"
BDGP_INS |  | Berkeley Drosophila Genome Project -- Insertion |  | /db_xref="BDGP_INS:123456"
BEEBASE |  | BeeBase |  | /db_xref="BEEBASE:GB55480"
BEETLEBASE |  | Tribolium Genome Database -- Insertion |  | /db_xref="BEETLEBASE:TC030551"
BEI |  | BEI Resources |  | /db_xref="BEI:NR-50065"
BGD |  | Bovine Genome Database |  | /db_xref="BGD:BT10004"
BOLD |  | Barcode of Life database |  | /db_xref="Bold:EPAF263"
CABRI |  | Common Access to Biological Resources and Information Project |  | /db_xref="CABRI:ACC 424"
CCAP |  | Culture Collection of Algae and Protozoa |  | /db_xref="CCAP:1460/15"
CDD |  | Conserved Domain Database |  | /db_xref="CDD:02194"
CGD |  | Candida Genome Database |  | /db_xref="CGD:CAL0005934"
dbEST |  | EST database maintained at the NCBI. |  | /db_xref="dbEST:123456" /db_xref="dbEST:BP535535"
dbProbe |  | NCBI Probe database Public registry of nucleic acid reagents |  | /db_xref="dbProbe:38"
dbSNP |  | Variation database maintained at the NCBI. |  | /db_xref="dbSNP:4647" /db_xref="dbSNP:rs133073"
dbSTS |  | STS database maintained at the NCBI. |  | /db_xref="dbSTS:456789" /db_xref="dbSTS:BV210161"
dictyBase |  | Dictyostelium genome database |  | /db_xref="dictyBase:DDB0191090"
ECOCYC |  | E. coli database |  | /db_xref="ECOCYC:sroC" /db_xref="ECOCYC:C0343"
EcoGene |  | Database of Escherichia coli Sequence and Function |  | /db_xref="EcoGene:EG11277"
ENSEMBL |  | Database of automatically annotated genomic data |  | /db_xref="ENSEMBL:HUMAN-Clone-AC005612" /db_xref="ENSEMBL:HUMAN-Gene-ENSG00000007102"
EnsemblGenomes |  | Extending Ensembl across taxonomic space |  | /db_xref="EnsemblGenomes:AAC73116" /db_xref="EnsemblGenomes:b0005"
EnsemblGenomes-Gn |  | EnsemblGenomes Gene |  | /db_xref="EnsemblGenomes-Gn"
EnsemblGenomes-Tr |  | EnsemblGenomes Transcript |  | /db_xref="EnsemblGenomes-Tr:MAPG_00606T0"
EPD |  | Eukaryotic Promoter Database |  | /db_xref="EPD:EP00576"
ERIC |  | Enteropathogen Resource Integration Center |  | db_xref="ERIC:ABY-0246137"
ESTLIB |  | EBI's EST library identifier |  | /db_xref="ESTLIB:1200"
FANTOM_DB |  | Database of Functional Annotation of Mouse |  | /db_xref="FANTOM_DB:0610005A07"
FBOL |  | International Fungal Working Group Fungal Barcoding. |  | /db_xref="FBOL:2224"
FLYBASE |  | Database of Genetic and molecular data of Drosophila. |  | /db_xref="FLYBASE:FBgn0000024"
Fungorum |  | Index Fungorum |  | /db_xref="Fungorum:ID550186"
GABI |  | Network of Different Plant Genomic Research Projects |  | /db_xref="GABI:HA05J18"
GDB |  | Human Genome Database accession numbers |  | /db_xref="GDB:G00-128-600"
GeneDB |  | Curated gene database for Leishmania major and Trypanosoma brucei |  | /db_xref="GeneDB:SPCC285.16c"
GeneID |  | Entrez Gene Database (replaces NCBI Locus Link) |  | /db_xref="GeneID:3054987"
GI |  | GenInfo identifier, used as a unique sequence identifier for nucleotide and proteins |  | /db_xref="GI:1234567890"
GO |  | Gene Ontology Database identifier |  | /db_xref="GO:123"
GOA |  | Gene Ontology Annotation Database Identifier |  | /db_xref=" GOA :P01100"
Greengenes |  | 16S rRNA gene database |  | /db_xref="Greengenes:269185"
GRIN |  | Germplasm Resources Information Network |  | /db_xref="GRIN:1005973"
HGNC |  | Human Gene Nomenclature Database |  | /db_xref="HGNC:HGNC:2041"
H-InvDB |  | H-Invitational Database |  | /db_xref="H-InvDB:HIT000000001" /db_xref="H-InvDB:HIX0000001”
HMP |  | Human Microbiome Project |  | /db_xref="HMP:0536"
HOMD |  | Human Oral Microbiome Database |  | /db_xref="HOMD:tax_078" /db_xref="HOMD:seq_1603”
HPM |  | Human Proteome Map |  | /db_xref="HPM:8106"
HSSP |  | Database of homology-derived secondary structure of proteins |  | /db_xref="HSSP:12GS
I5KNAL |  | i5k Workspace |  | /db_xref="I5KNAL:OFAS008986"
IKMC |  | International Knockout Mouse Consortium |  | /db_xref="IKMC:66303"
IMGT/GENE-DB |  | Immunogenetics database, immunoglobulin and T-cell receptor genes |  | /db_xref="IMGT/GENE-DB:IGKC"
IMGT/LIGM |  | Immunogenetics database, immunoglobulins and T-cell receptors |  | /db_xref="IMGT/LIGM:U03895"
IMGT/HLA |  | Immunogenetics database, human MHC |  | /db_xref="IMGT/HLA:HLA00031"
InterPro |  | InterPro protein sequence database |  | /db_xref="InterPro:IPR002928"
IntrepidBio |  | Intrepid BioInformatics |  | /db_xref="IntrepidBio:5259707746"
IRD |  | Influenza Research Database |  | /db_xref="IRD:CEIRS-CIP045-123456.2"
ISFinder |  | Insertion sequence elements database |  | /db_xref="ISFinder:ISA1083-2"
ISHAM-ITS |  | ITS reference database for pathogenic fungi |  | /db_xref="ISHAM-ITS:MITS310"
JCM |  | Japan Collection of Microorganisms |  | /db_xref="JCM:1339"
JGIDB |  | JGI Genome Portal |  | /db_xref="JGIDB:Chluvu1_81011"
LocusID |  | NCBI LocusLink ID **Discontinued March 2005 |  | /db_xref="LocusID:51199"
MaizeGDB |  | Maize Genome Database unique identifiers |  | /db_xref="MaizeGDB:635633 "
MarpolBase |  | Genome Database for Marchantia polymorpha |  | /db_xref="MarpolBase:Mp1g00010.1 "
MedGen |  | Human Medical Genetics |  | /db_xref="MedGen:C0010674"
MGI |  | Mouse Genome Informatics |  | /db_xref="MGI:MGI:1894891"
MIM |  | Mendelian Inheritance in Man numbers |  | /db_xref="MIM:123456"
miRBase |  | miRNA Database |  | /db_xref="miRBase:MI0000681"
MycoBank |  | Fungal Nomenclature and Species Bank |  | /db_xref="MycoBank:8284"
NBRC |  | NITE Biological Resource Center |  | /db_xref="NBRC:3189"
NextDB |  | Nematode Expression Pattern DataBase |  | /db_xref="NextDB:CELK01662"
niaEST |  | NIA Mouse cDNA Project |  | /db_xref="niaEST:L0304H12-3"
NMPDR |  | National Microbial Pathogen Data Resource |  | /db_xref="NMPDR:fig|306254.1.peg.183"
NRESTdb |  | Natural Rubber EST database |  | /db_xref="NRESTdb:Y01A01"
OrthoMCL |  | Ortholog Groups of Protein Sequences |  | /db_xref="OrthoMCL:OG5_130679"
Osa1 |  | Rice Genome Annotation Project |  | /db_xref="Osa1:LOC_Os01g12345"
Pathema |  | Pathema Genome Resource |  | /db_xref="Pathema:BA_4405" /db_xref="Pathema:191218"
PBmice |  | PiggyBac Mutagenesis Information Center |  | /db_xref="PBmice:38"
PDB |  | Biological macromolecule three dimensional structure database |  | /dbxref="PDB:12GS"
PFAM |  | Collection of protein families |  | /db_xref="PFAM:PF00003
PGN |  | Plant Genome Network |  | /db_xref="PGN:aam01-1ms3-a05"
JGI Phytozome |  | Plant Genome Network |  | /db_xref="Phytozome:Glyma0021s00410" /db_xref="Phytozome:ppb016588m_2_1.p"
PIR |  | Protein Information Resource accession numbers |  | /db_xref="PIR:S12345"
PomBase |  | Database of Structural and Functional Data for Schizosaccaromyces pombe |  | /db_xref="PomBase:SPBC11B10.09"
PSEUDO |  | EMBL pseudo protein identifier |  | /db_xref="PSEUDO:CAC44644.1"
PseudoCAP |  | Pseudomonas Genome Database |  | /db_xref="PseudoCap:PA0001"
RAP-DB |  | Rice Annotation Project Database |  | /db_xref="RAP-DB:Os01g1234567"
RATMAP |  | Rat Genome Database |  | /db_xref="RATMAP:5"
RBGE_garden |  | Royal Botanic Garden Edinburgh Living Collections |  | /db_xref="RBGE_garden:20021433"
RBGE_herbarium |  | Royal Botanic Garden Edinburgh Herbarium |  | /db_xref="RBGE_herbarium:E00217291"
RFAM |  | RNA families database of alignments and CMs |  | /db_xref="RFAM:RF00230"
RGD |  | Rat Genome Database |  | /db_xref="RGD:620528"
RiceGenes |  | Rice database accession numbers |  | /db_xref="RiceGenes:AA231856"
RNAcentral |  | Noncoding RNA Sequence Database |  | /db_xref="RNAcentral:URS00001B9622_9606"
RZPD |  | Resource Centre Primary Database Clone Identifiers |  | /db_xref="RZPD:IMAGp998I142450Q6"
SEED |  | The SEED Database |  | /db_xref="SEED:fig|83331.1.peg.1"
SGD |  | Saccharomyces Genome Database |  | /db_xref="SGD:L0000470"
SGN |  | SOL Genomics Network |  | /db_xref="SGN:E553090"
SK-FST |  | Saskatoon Arabidopsis T-DNA mutant population - SK Collection |  | /db_xref="SK-FST: FST:SK32219"
SoyBase |  | Glycine max Genome Database |  | /db_xref="SoyBase:Satt005"
SRPDB |  | Signal Recognition Particle Database |  | /db_xref="SRPDB:Arth.aure._CP000474"
SubtiList |  | Bacillus subtilis genome sequencing project |  | /db_xref="SubtiList:BG10001"
TAIR |  | Arabidopsis IR |  | /db_xref="TAIR:AT1F51370"
taxon |  | NCBI's taxonomic identifier |  | /db_xref="taxon:4932"
TIGRFAM |  | TIGR protein families |  | /db_xref="TIGRFAM:TIGR00094"
TubercuList |  | TubercuList knowledge base |  | /db_xref="TubercuList:Rv3322c"
UNILIB |  | Unified Library Database, a library-level view of the EST and SAGE libraries present in dbEST, UniGene and SAGEmap |  | /db_xref="UNILIB:1002"
UniProtKB/Swiss-Prot |  | section of the UniProt Knowledgebase, containing annotated records, which include curator-evaluated computational analysis, as well as, information extracted from the literature |  | /db_xref="UniProtKB/Swiss-Prot:P12345"
UniProtKB/TrEMBL |  | section of the UniProt Knowledgebase, containing computationally analysed records waiting for full manual annotation |  | /db_xref=" UniProtKB/TrEMBL:Q00177"
UniSTS |  | Database of Sequence Tagged Sites |  | /db_xref=" UniSTS:486599"
UNITE |  | Molecular database for the identification of fungi |  | /db_xref=" UNITE:UDB000157"
VBASE2 |  | Integrative database of germ-line V genes from the immunoglobulin loci of human and mouse |  | /db_xref="VBASE2:humIGKV165"
ViPR |  | Virus Pathogen Resource |  | /db_xref="ViPR:HRV-A34_p1058_sR263_2008"
VISTA |  | Vista Enhancer Browser |  | db_xref="VISTA:hs123"
VectorBase |  | Bioinformatics Resource Center for Invertebrate Vectors of Human Pathogens |  | db_xref="VectorBase:ENSANGG00000007825"
VGNC |  | Vertebrate Gene Nomenclature Committee |  | db_xref="VGNC:VGNC:4927"
WorfDB |  | C. elegans ORFeome cloning project |  | /db_xref="WorfDB:pos-1"
WormBase |  | Caenorhabditis elegans Genome Database |  | /db_xref="WormBase:R13H7"
Xenbase |  | Xenopus laevis and tropicalis biology and genomics resource |  | /db_xref=Xenbase:XB-GENE-1019547
ZFIN |  | Zebrafish Information Network |  | /db_xref="ZFIN:ZDB-GENE-011205-17"

## INSDC Members

### DDBJ

- Submission
- Sequence Retrieval

### ENA

- Submission
- Sequence Retrieval

### GenBank

- Submission
- Sequence Retrival

Support Center

Last updated: 2017-11-13T23:20:57Z